import $ from 'jquery';

class Menu
{
    constructor(el, baseUri)
    {
        this.$el = $(el);
        this.$back = this.$el.find('.vehicle-select__menu-back');
        this.$body = this.$el.find('.vehicle-select__menu-body');
        this.$loader = this.$body.find('.vehicle-select__menu-loader');
        this.$content = this.$body.find('.vehicle-select__menu-content');

        this.baseUri = baseUri;

        this.cache = {};
        this.current = false;

        this.$back.on('click', function(e) {
            e.preventDefault();
            $(this).trigger('back');
        }.bind(this));

        this.$el.on('click', '.menu__link', function(e) {
            e.preventDefault();

            let $link = $(e.target);
            $(this).trigger('select', [$link.data('type'), $link.data('value'), $link.text()]);
        }.bind(this));
    }

    load(path)
    {
        if (this.current) {
            this.cache[this.current] = this.$content.html();
        }

        if (this.cache[path] === undefined) {
            this.$loader.addClass('in');
            this.$content.removeClass('in');

            $.get(this.baseUri + path, function(content) {
                this.current = path;

                $.each(tecdocTranslations, function(search, replace) {
                    let regex = new RegExp(search);
                    content = content.replace(regex, replace);
                });

                this.$content.html(content);
                this.$content.scrollTop(0);
                this.$content.addClass('in');
                this.$loader.removeClass('in');
            }.bind(this));

        } else {
            this.$content.html(this.cache[path]);
            this.$content.scrollTop(0);
            this.current = path;
        }
    }

    show()
    {
        this.$el.addClass('open');
    }

    hide()
    {
        this.$el.removeClass('open');
    }
}

export default class VehicleSelect
{
    constructor(el)
    {
        this.$el = $(el);
        this.$el.on('submit', this.onSubmit.bind(this));

        this.step = 0;

        this.inputs = {
            $manufacturer: this.$el.find('[name="manufacturer"]'),
            $model: this.$el.find('[name="model"]'),
            $vehicle: this.$el.find('[name="vehicle"]')
        };

        this.$manufacturer = this.$el.find('.manufacturer');
        this.$manufacturer.on('click', this.onManufacturerClick.bind(this));
        this.setManufacturer(this.inputs.$manufacturer.val(), this.$manufacturer.text());

        this.$model = this.$el.find('.model');
        this.$model.on('click', this.onModelClick.bind(this));
        this.setModel(this.inputs.$model.val(), this.$model.text());

        this.$vehicle = this.$el.find('.vehicle');
        this.$vehicle.on('click', this.onVehicleClick.bind(this));
        this.setVehicle(this.inputs.$vehicle.val(), this.$vehicle.text());

        this.menu = new Menu(this.$el.find('.vehicle-select__menu'), this.$el.attr('action'));
        $(this.menu)
            .on('back', this.onBack.bind(this))
            .on('select', this.onSelect.bind(this));
    }

    get manufacturer()
    {
        return this.inputs.$manufacturer.val();
    }

    set manufacturer(value)
    {
        this.inputs.$manufacturer.val(value ? value : '');
    }

    get model()
    {
        return this.inputs.$model.val();
    }

    set model(value)
    {
        this.inputs.$model.val(value ? value : '');
    }

    get vehicle()
    {
        return this.inputs.$vehicle.val();
    }

    set vehicle(value)
    {
        this.inputs.$vehicle.val(value ? value : '');
    }

    setStep(step)
    {
        step = step < 0 ? 0 : step;

        if (step > this.step) {
            this.menu.show();
        } else if (0 === step) {
            this.menu.hide();
        }

        switch (step) {
            case 3:
                if (this.manufacturer && this.model) {
                    this.menu.load('/vehicles/' + this.manufacturer + '/' + this.model);
                } else {
                    this.setStep(2);
                    return;
                }
                break;
            case 2:
                if (this.manufacturer) {
                    this.menu.load('/models/' + this.manufacturer);
                } else {
                    this.setStep(1);
                    return;
                }
                break;
            case 1:
                this.menu.load('/manufacturers');
                break;
        }

        this.step = step;
    }

    onManufacturerClick()
    {
        this.setStep(1);
    }

    onModelClick()
    {
        this.setStep(2);
    }

    onVehicleClick()
    {
        this.setStep(3);
    }

    setManufacturer(value, label)
    {
        value = value || false;

        if (value !== this.manufacturer) {
            this.manufacturer = value;
            this.$manufacturer.text(
                value ? label : this.$manufacturer.data('placeholder')
            );
        }
    }

    setModel(value, label)
    {
        value = value || false;

        if (value !== this.model) {
            this.model = value;
            this.$model.text(
                value ? label : this.$model.data('placeholder')
            );
        }
    }

    setVehicle(value, label)
    {
        value = value || false;

        if (value !== this.vehicle) {
            this.vehicle = value;
            this.$vehicle.text(
                value ? label : this.$vehicle.data('placeholder')
            );
        }

        if (value) {
            this.$el.submit();
        }
    }

    onBack()
    {
        this.setStep(this.step - 1);
    }

    onSelect(e, type, value, label)
    {
        switch (type) {
            case 'vehicle':
                this.setVehicle(value, label);
                this.menu.hide();
                break;
            case 'manufacturer':
                this.setManufacturer(value, label);
                this.onModelClick();
                break;
            case 'model':
                this.setModel(value, label);
                this.onVehicleClick();
                break;
        }
    }

    onSubmit(e)
    {
        if (!this.vehicle) {
            e.preventDefault();


        }
    }
}