<?php
namespace Ep\TecDoc\Hydrator;

use Zend\Hydrator\HydratorInterface;
use Zend\Hydrator\HydratorPluginManager;
use Zend\Hydrator\Reflection as ReflectionHydrator;

/**
 * Class DeepReflectionHydrator
 *
 * @package Ep\TecDoc\Hydrator
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class DeepReflectionHydrator extends ReflectionHydrator
{
    /** @var HydratorPluginManager */
    protected $hydrators;

    public function __construct(HydratorPluginManager $hydrators)
    {
        parent::__construct();
        $this->hydrators = $hydrators;
    }

    /**
     * Hydrate $object with the provided $data.
     *
     * @param  array $data
     * @param  object $object
     * @return object
     */
    public function hydrate(array $data, $object)
    {
        $reflProperties = self::getReflProperties($object);
        foreach ($data as $key => $value) {
            $name = $this->hydrateName($key, $data);
            if (isset($reflProperties[$name])) {
                $comment = $reflProperties[$name]->getDocComment();

                if (is_array($value) && preg_match('#/\*\* @var ([^ ]+) \*/#', $comment, $matches)) {
                    $class = $matches[1];

                    if (class_exists($class)) {
                        /** @var HydratorInterface $hydrator */
                        $hydrator = $this->hydrators->get(ltrim($class, '\\'));
                        $value = $hydrator->hydrate($value, new $class());
                    }
                }

                $reflProperties[$name]->setValue($object, $this->hydrateValue($name, $value, $data));
            }
        }
        return $object;
    }
}