<?php
namespace Ep\TecDoc\Record;

use Ep\Filter\SanitizeInput;

/**
 * Class VehicleByIdRecord
 *
 * @package Ep\TecDoc\Record
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
class VehicleByIdRecord implements RecordInterface
{
    use Traits\ConstructionPeriodTrait;

    /** @var string */
    protected $axisConfiguration;
    /** @var string */
    protected $brakeSystem;
    /** @var int */
    protected $carId;
    /** @var int */
    protected $ccmTech;
    /** @var string */
    protected $constructionType;
    /** @var int */
    protected $cylinder;
    /** @var int */
    protected $cylinderCapacityCcm;
    /** @var int */
    protected $cylinderCapacityLiter;
    /** @var string */
    protected $fuelType;
    /** @var  */
    protected $fuelTypeProcess;
    /** @var string */
    protected $impulsionType;
    /** @var int */
    protected $manuId;
    /** @var string */
    protected $manuName;
    /** @var int */
    protected $modId;
    /** @var string */
    protected $modelName;
    /** @var string */
    protected $motorType;
    /** @var int */
    protected $powerHpFrom;
    /** @var int */
    protected $powerHpTo;
    /** @var int */
    protected $powerKwFrom;
    /** @var int */
    protected $powerKwTo;
    /** @var int */
    protected $tonnage;
    /** @var string */
    protected $typeName;
    /** @var string */
    protected $typeNumber;
    /** @var int */
    protected $valves;
    /** @var int */
    protected $yearOfConstrFrom;
    /** @var int */
    protected $yearOfConstrTo;

    /** @var SanitizeInput */
    protected $slugFilter;
    /** @var string */
    protected $slug;

    protected function getSlugFilter(): SanitizeInput
    {
        if (null === $this->slugFilter) {
            $this->slugFilter = new SanitizeInput();
        }

        return $this->slugFilter;
    }

    public function getSlug(): string
    {
        if (null === $this->slug) {
            $filter = $this->getSlugFilter();

            $this->slug = implode('--', [
                $filter->filter($this->getManufacturerName()),
                implode('-', [$filter->filter($this->modelName), $this->modId]),
                implode('-', [
                    $filter->filter($this->typeName),
                    $this->powerKwFrom . 'kw',
                    $this->carId,
                ]),
            ]);
        }

        return $this->slug;
    }

    /**
     * @return string
     */
    public function getAxisConfiguration(): string
    {
        return $this->axisConfiguration;
    }

    /**
     * @return string
     */
    public function getBrakeSystem(): string
    {
        return $this->brakeSystem;
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->carId;
    }

    /**
     * @return int
     */
    public function getCcmTech(): int
    {
        return $this->ccmTech;
    }

    /**
     * @return string
     */
    public function getConstructionType(): string
    {
        return $this->constructionType;
    }

    /**
     * @return int
     */
    public function getCylinder(): int
    {
        return $this->cylinder;
    }

    /**
     * @return int
     */
    public function getCylinderCapacityCcm(): int
    {
        return $this->cylinderCapacityCcm;
    }

    /**
     * @return int
     */
    public function getCylinderCapacityLiter(): int
    {
        return $this->cylinderCapacityLiter;
    }

    /**
     * @return string
     */
    public function getFuelType(): string
    {
        return $this->fuelType;
    }

    /**
     * @return mixed
     */
    public function getFuelTypeProcess()
    {
        return $this->fuelTypeProcess;
    }

    /**
     * @return string
     */
    public function getImpulsionType(): string
    {
        return $this->impulsionType;
    }

    /**
     * @return int
     */
    public function getManufacturerId(): int
    {
        return $this->manuId;
    }

    /**
     * @return string
     */
    public function getManufacturerName(): string
    {
        return $this->manuName === 'SKODA' ? 'ŠKODA' : $this->manuName;
    }

    /**
     * @return int
     */
    public function getModelId(): int
    {
        return $this->modId;
    }

    /**
     * @return string
     */
    public function getModelName(): string
    {
        return $this->modelName;
    }

    /**
     * @return string
     */
    public function getMotorType(): string
    {
        return $this->motorType;
    }

    /**
     * @return int
     */
    public function getPowerHpFrom(): int
    {
        return $this->powerHpFrom;
    }

    /**
     * @return int
     */
    public function getPowerHpTo(): int
    {
        return $this->powerHpTo;
    }

    /**
     * @return int
     */
    public function getPowerKwFrom(): int
    {
        return $this->powerKwFrom;
    }

    /**
     * @return int
     */
    public function getPowerKwTo(): int
    {
        return $this->powerKwTo;
    }

    /**
     * @return int
     */
    public function getTonnage(): int
    {
        return $this->tonnage;
    }

    /**
     * @return string
     */
    public function getTypeName(): string
    {
        return $this->typeName;
    }

    /**
     * @return string
     */
    public function getTypeNumber(): string
    {
        return $this->typeNumber;
    }

    /**
     * @return int
     */
    public function getValves(): int
    {
        return $this->valves;
    }

    /**
     * @return int
     */
    public function getYearOfConstrFrom(): int
    {
        return $this->yearOfConstrFrom;
    }

    /**
     * @return int
     */
    public function getYearOfConstrTo(): int
    {
        return $this->yearOfConstrTo;
    }
}