<?php
namespace Ep\TecDoc\Request;

class DynamicAddressRequest extends AbstractRequest
{
    /** @var string */
    protected $address;

    /** @var int */
    protected $validityHours;

    /**
     * @return string
     */
    public function getAddress()
    {
        return $this->address;
    }

    /**
     * @param string $address
     */
    public function setAddress($address)
    {
        if (filter_var($address, FILTER_VALIDATE_IP)):
            throw new \InvalidArgumentException('Neispravna IP adresa!');
        endif;

        $this->address = $address;
    }


    /**
     * @return int
     */
    public function getValidityHours()
    {
        return $this->validityHours;
    }

    /**
     * @param int $validityHours
     */
    public function setValidityHours(int $validityHours)
    {
        if ($validityHours < 1 || $validityHours > 24 || ! is_int($validityHours)):
            throw new \InvalidArgumentException('validityHours mora biti integer između 1 i 24');
        endif;
        $this->validityHours = $validityHours;
    }

    public function toJson()
    {
        $params = [
            'addDynamicAddress' => [
                'address'  => $this->address,
                'provider' => $this->provider,
            ],
        ];
        if (null !== $this->validityHours) :
            $params['addDynamicAddress']['validityHours'] = $this->validityHours;
        endif;

        return json_encode($params);
    }


}