<?php
namespace Ep\TecDoc\Response;

use Ep\TecDoc\Record\Seq\RecordSeqInterface;
use Traversable;

/**
 * Osnovna klasa za TecDoc odgovore.
 *
 * @package Ep\TecDoc\Response
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
abstract class AbstractResponse implements ResponseInterface
{
    /** @var RecordSeqInterface */
    protected $data;
    /** @var int */
    protected $status;
    /** @var string */
    protected $statusText;

    /**
     * @return int
     */
    public function count()
    {
        return count($this->data);
    }

    /**
     * @return RecordSeqInterface
     */
    public function getData(): ?RecordSeqInterface
    {
        return $this->data;
    }

    /**
     * @return int
     */
    public function getStatus(): int
    {
        return $this->status;
    }

    /**
     * @return string
     */
    public function getStatusText(): ?string
    {
        return $this->statusText;
    }

    /**
     * Retrieve an external iterator
     * @link http://php.net/manual/en/iteratoraggregate.getiterator.php
     * @return Traversable An instance of an object implementing <b>Iterator</b> or
     * <b>Traversable</b>
     * @since 5.0.0
     */
    public function getIterator()
    {
        return $this->getData()->getIterator();
    }
}