<?php
namespace Ep\TecDoc;

use Ep\TecDoc\Record\ManufacturersRecord;
use Ep\TecDoc\Record\ModelSeriesRecord;
use Ep\TecDoc\Record\VehicleByIdRecord;
use Ep\TecDoc\Record\VehicleByIds4Record;
use Ep\TecDoc\Record\VehicleIdsByCriteriaRecord;
use Ep\TecDoc\Request\ModelSeriesRequest;

/**
 * Interface TecDocInterface
 *
 * @package Ep\TecDoc
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/tecdoc
 */
interface TecDocInterface
{
    /**
     * @return array
     */
    public function getConfig(): array;

    /**
     * @param array $config
     */
    public function setConfig(array $config): void;

    /**
     * @return VehicleByIdRecord|null
     */
    public function getCurrentVehicle(): ?VehicleByIdRecord;

    /**
     * @param VehicleByIdRecord|int|string|null $vehicle
     */
    public function setCurrentVehicle($vehicle): void;

    /**
     * @return ManufacturersRecord[]
     */
    public function getFeaturedManufacturers(): array;

    /**
     * @return ManufacturersRecord[]
     */
    public function getManufacturers(): array;

    /**
     * @param ManufacturersRecord|int $manufacturer
     * @param ModelSeriesRequest|null $request
     *
     * @return ModelSeriesRecord[]
     */
    public function getModelSeries($manufacturer): array;

    /**
     * @param ManufacturersRecord|int $manufacturer
     * @param ModelSeriesRecord|int $model
     *
     * @return VehicleIdsByCriteriaRecord[]
     */
    public function getVehicleIdsByCriteria($manufacturer, $model): array;

    /**
     * @param int $id
     *
     * @return VehicleByIdRecord
     */
    public function getVehicleById(int $id): VehicleByIdRecord;

    /**
     * @param int[] $vehicleIds
     *
     * @return VehicleByIds4Record[]
     */
    public function getVehicleByIds4(array $vehicleIds): array;

    /**
     * @param ManufacturersRecord|int $manufacturer
     * @param ModelSeriesRecord|int $model
     *
     * @return VehicleByIdRecord[]
     */
    public function getVehicles($manufacturer, $model): array;
}